# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/array_job.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/array_job.proto',
  package='flyteidl.plugins',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n flyteidl/plugins/array_job.proto\x12\x10\x66lyteidl.plugins\"w\n\x08\x41rrayJob\x12\x13\n\x0bparallelism\x18\x01 \x01(\x03\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12\x17\n\rmin_successes\x18\x03 \x01(\x03H\x00\x12\x1b\n\x11min_success_ratio\x18\x04 \x01(\x02H\x00\x42\x12\n\x10success_criteriaB9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
)




_ARRAYJOB = _descriptor.Descriptor(
  name='ArrayJob',
  full_name='flyteidl.plugins.ArrayJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parallelism', full_name='flyteidl.plugins.ArrayJob.parallelism', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='flyteidl.plugins.ArrayJob.size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_successes', full_name='flyteidl.plugins.ArrayJob.min_successes', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_success_ratio', full_name='flyteidl.plugins.ArrayJob.min_success_ratio', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='success_criteria', full_name='flyteidl.plugins.ArrayJob.success_criteria',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=54,
  serialized_end=173,
)

_ARRAYJOB.oneofs_by_name['success_criteria'].fields.append(
  _ARRAYJOB.fields_by_name['min_successes'])
_ARRAYJOB.fields_by_name['min_successes'].containing_oneof = _ARRAYJOB.oneofs_by_name['success_criteria']
_ARRAYJOB.oneofs_by_name['success_criteria'].fields.append(
  _ARRAYJOB.fields_by_name['min_success_ratio'])
_ARRAYJOB.fields_by_name['min_success_ratio'].containing_oneof = _ARRAYJOB.oneofs_by_name['success_criteria']
DESCRIPTOR.message_types_by_name['ArrayJob'] = _ARRAYJOB
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ArrayJob = _reflection.GeneratedProtocolMessageType('ArrayJob', (_message.Message,), dict(
  DESCRIPTOR = _ARRAYJOB,
  __module__ = 'flyteidl.plugins.array_job_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.ArrayJob)
  ))
_sym_db.RegisterMessage(ArrayJob)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
